@@ -1,7 +1,39 @@
-//----------------------------------*-C++-*----------------------------------//
-// Copyright 1998-1999 The Regents of the University of California. 
-// All rights reserved. See LEGAL.LLNL for full text and disclaimer.
-//---------------------------------------------------------------------------//
+//-----------------------------------------------------------------------------
+//
+// Copyright (c) 1998 - 2007, The Regents of the University of California
+// Produced at the Lawrence Livermore National Laboratory
+// All rights reserved.
+//
+// This file is part of PyCXX. For details, see http://cxx.sourceforge.net. The
+// full copyright notice is contained in the file COPYRIGHT located at the root
+// of the PyCXX distribution.
+//
+// Redistribution  and  use  in  source  and  binary  forms,  with  or  without
+// modification, are permitted provided that the following conditions are met:
+//
+//  - Redistributions of  source code must  retain the above  copyright notice,
+//    this list of conditions and the disclaimer below.
+//  - Redistributions in binary form must reproduce the above copyright notice,
+//    this  list of  conditions  and  the  disclaimer (as noted below)  in  the
+//    documentation and/or materials provided with the distribution.
+//  - Neither the name of the UC/LLNL nor  the names of its contributors may be
+//    used to  endorse or  promote products derived from  this software without
+//    specific prior written permission.
+//
+// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT  HOLDERS AND CONTRIBUTORS "AS IS"
+// AND ANY EXPRESS OR  IMPLIED WARRANTIES, INCLUDING,  BUT NOT  LIMITED TO, THE
+// IMPLIED WARRANTIES OF MERCHANTABILITY AND  FITNESS FOR A PARTICULAR  PURPOSE
+// ARE  DISCLAIMED.  IN  NO  EVENT  SHALL  THE  REGENTS  OF  THE  UNIVERSITY OF
+// CALIFORNIA, THE U.S.  DEPARTMENT  OF  ENERGY OR CONTRIBUTORS BE  LIABLE  FOR
+// ANY  DIRECT,  INDIRECT,  INCIDENTAL,  SPECIAL,  EXEMPLARY,  OR CONSEQUENTIAL
+// DAMAGES (INCLUDING, BUT NOT  LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR
+// SERVICES; LOSS OF  USE, DATA, OR PROFITS; OR  BUSINESS INTERRUPTION) HOWEVER
+// CAUSED  AND  ON  ANY  THEORY  OF  LIABILITY,  WHETHER  IN  CONTRACT,  STRICT
+// LIABILITY, OR TORT  (INCLUDING NEGLIGENCE OR OTHERWISE)  ARISING IN ANY  WAY
+// OUT OF THE  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
+// DAMAGE.
+//
+//-----------------------------------------------------------------------------
 
 #ifdef _MSC_VER
 // disable warning C4786: symbol greater than 255 character,
@@ -9,8 +41,6 @@
 #pragma warning(disable: 4786)
 #endif
 
-
-#include "Python.h"
 #include "CXX/Objects.hxx"
 #include "CXX/Extensions.hxx"
 
@@ -49,6 +79,83 @@ static std::string test_String()
     return "ok";
 }
 
+static std::string
+test_boolean()
+{
+    bool passed = true;
+
+    Py::Object o;
+    Py::Boolean pb1;
+    Py::Boolean pb2;
+    bool b1;
+
+    o = Py::True();
+    if( o.isTrue() )
+        { std::cout << "OK: T1: True" << std::endl; }
+    else
+        { std::cout << "Bad: T1: False" << std::endl; passed = false; }
+
+    pb1 = o;
+    if( pb1 )
+        { std::cout << "OK: T2: True" << std::endl; }
+    else
+        { std::cout << "Bad: T2: False" << std::endl; passed = false; }
+
+    b1 = pb1;
+    if( b1 )
+        { std::cout << "OK: T3: True" << std::endl; }
+    else
+        { std::cout << "Bad: T3: False" << std::endl; passed = false; }
+
+    pb2 = pb1;
+    if( pb2 )
+        { std::cout << "OK: T4: True" << std::endl; }
+    else
+        { std::cout << "Bad: T4: False" << std::endl; passed = false; }
+
+    pb2 = true;
+    if( pb2 )
+        { std::cout << "OK: T5: True" << std::endl; }
+    else
+        { std::cout << "Bad: T5: False" << std::endl; passed = false; }
+
+
+    o = Py::False();
+    if( o.isTrue() )
+        { std::cout << "Bad: F1: True" << std::endl; passed = false; }
+    else
+        { std::cout << "OK: F1: False" << std::endl; }
+
+    pb1 = o;
+    if( pb1 )
+        { std::cout << "Bad: F2: True" << std::endl; passed = false; }
+    else
+        { std::cout << "OK: F2: False" << std::endl; }
+
+    b1 = pb1;
+    if( b1 )
+        { std::cout << "Bad: F3: True" << std::endl; passed = false; }
+    else
+        { std::cout << "OK: F3: False" << std::endl; }
+
+    pb2 = pb1;
+    if( pb2 )
+        { std::cout << "Bad: F4: True" << std::endl; passed = false; }
+    else
+        { std::cout << "OK: F4: False" << std::endl; }
+
+    pb2 = false;
+    if( pb2 )
+        { std::cout << "Bad: F5: True" << std::endl; passed = false; }
+    else
+        { std::cout << "OK: F5: False" << std::endl; }
+
+    if( passed )
+        return "ok";
+    else
+        return "failed";
+}
+
 static std::string
 test_numbers()
 {
@@ -402,23 +509,23 @@ private:
         std::cout << "ex_string: s1.size() " << s1.size() << std::endl;
 
         if( s1.isUnicode() )
-    {
+        {
             std::cout << "ex_string: s2 is s1.encode( utf-8 )" << std::endl;
             Py::String s2( s1.encode( "utf-8" ) );
             std::cout << "ex_string: s2.isString() " << s2.isString() << std::endl;
             std::cout << "ex_string: s2.isUnicode() " << s2.isUnicode() << std::endl;
             std::cout << "ex_string: s2.size() " << s2.size() << std::endl;
             return s2;
-    }
+        }
         else
-    {
+        {
             std::cout << "ex_string: s2 is s1.decode( utf-8 )" << std::endl;
             Py::String s2( s1.decode( "utf-8" ) );
             std::cout << "ex_string: s2.isString() " << s2.isString() << std::endl;
             std::cout << "ex_string: s2.isUnicode() " << s2.isUnicode() << std::endl;
             std::cout << "ex_string: s2.size() " << s2.size() << std::endl;
             return s2;
-    }
+        }
     }
 
     Py::Object ex_sum (const Py::Tuple &a)
@@ -466,6 +573,9 @@ private:
         }
         debug_check_ref_queue();
 
+        std::string result = test_boolean();
+        std::cout << "Py::Boolean: " << result << std::endl;
+        debug_check_ref_queue();
         std::cout << "Numbers: " << test_numbers() << std::endl;
         debug_check_ref_queue();
         std::cout << "Py::String: " << test_String() << std::endl;
